#include "rect.h"

#ifndef __BLOB_H__
#define __BLOB_H__

typedef struct _BlobSpan BlobSpan;
typedef struct _Blob Blob;

struct _BlobSpan {
  int left;
  int right;
};

struct _Blob {
  int y;
  int height;
  BlobSpan data[0];		/* slightly in violation of ANSI-C? */
};


Blob *blob_convex_union (Blob *b1, Blob *b2);
Blob *blob_ellipse (double xc, double yc, double xp, double yp, double xq, double yq);
void blob_bounds(Blob *b, rect *r);

#endif __BLOB_H__
